CMS Forms
==================
|Pypi|

A plugin to manage status updates of members in your CMS project.

This plugin is **only intended to be used with a CMS project**,
and not directly in any django project. To use in an independent
django project, you might need to configure your project.

.. |Pypi| image:: https://img.shields.io/pypi/v/cms-status.svg
   :target: https://pypi.python.org/pypi/cms-status
   :alt: Pypi


